@@ -15,16 +15,22 @@
 
 import logging
 
+from debtcollector import removals
 from six.moves.urllib import parse as urlparse
 
 from keystoneclient import exceptions
 from keystoneclient import httpclient
-from keystoneclient.i18n import _, _LE
+from keystoneclient.i18n import _
 
 
 _logger = logging.getLogger(__name__)
 
 
+# NOTE(jamielennox): To be removed after Pike.
+@removals.removed_class('keystoneclient.generic.client.Client',
+                        message='Use keystoneauth discovery',
+                        version='3.9.0',
+                        removal_version='4.0.0')
 class Client(httpclient.HTTPClient):
     """Client for the OpenStack Keystone pre-version calls API.
 
@@ -75,18 +81,18 @@ class Client(httpclient.HTTPClient):
             return self._local_keystone_exists()
 
     def _local_keystone_exists(self):
-        """Checks if Keystone is available on default local port 35357."""
+        """Check if Keystone is available on default local port 35357."""
         results = self._check_keystone_versions("http://localhost:35357")
         if results is None:
             results = self._check_keystone_versions("https://localhost:35357")
         return results
 
     def _check_keystone_versions(self, url):
-        """Calls Keystone URL and detects the available API versions."""
+        """Call Keystone URL and detects the available API versions."""
         try:
-            resp, body = self.request(url, "GET",
-                                      headers={'Accept':
-                                               'application/json'})
+            resp, body = self._request(url, "GET",
+                                       headers={'Accept':
+                                                'application/json'})
             # Multiple Choices status code is returned by the root
             # identity endpoint, with references to one or more
             # Identity API versions -- v3 spec
@@ -125,7 +131,7 @@ class Client(httpclient.HTTPClient):
             else:
                 raise exceptions.from_response(resp, "GET", url)
         except Exception:
-            _logger.exception(_LE('Failed to detect available versions.'))
+            _logger.exception('Failed to detect available versions.')
 
     def discover_extensions(self, url=None):
         """Discover Keystone extensions supported.
@@ -144,13 +150,13 @@ class Client(httpclient.HTTPClient):
             return self._check_keystone_extensions(url)
 
     def _check_keystone_extensions(self, url):
-        """Calls Keystone URL and detects the available extensions."""
+        """Call Keystone URL and detects the available extensions."""
         try:
             if not url.endswith("/"):
                 url += '/'
-            resp, body = self.request("%sextensions" % url, "GET",
-                                      headers={'Accept':
-                                               'application/json'})
+            resp, body = self._request("%sextensions" % url, "GET",
+                                       headers={'Accept':
+                                                'application/json'})
             if resp.status_code in (200, 204):  # some cases we get No Content
                 if 'extensions' in body and 'values' in body['extensions']:
                     # Parse correct format (per contract)
@@ -169,11 +175,11 @@ class Client(httpclient.HTTPClient):
                 raise exceptions.from_response(
                     resp, "GET", "%sextensions" % url)
         except Exception:
-            _logger.exception(_LE('Failed to check keystone extensions.'))
+            _logger.exception('Failed to check keystone extensions.')
 
     @staticmethod
     def _get_version_info(version, root_url):
-        """Parses version information.
+        """Parse version information.
 
         :param version: a dict of a Keystone version response
         :param root_url: string url used to construct
@@ -192,7 +198,7 @@ class Client(httpclient.HTTPClient):
 
     @staticmethod
     def _get_extension_info(extension):
-        """Parses extension information.
+        """Parse extension information.
 
         :param extension: a dict of a Keystone extension response
         :returns: tuple - (alias, name)
