@@ -10,12 +10,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
 import uuid
 
-from keystoneauth1 import fixture
-import six
+from oslo_serialization import jsonutils
 
+from keystoneauth1 import fixture
+
+from keystoneauth1 import session as auth_session
 from keystoneclient.auth import token_endpoint
 from keystoneclient import exceptions
 from keystoneclient import session
@@ -75,10 +76,10 @@ class KeystoneClientTest(utils.TestCase):
                                password='password',
                                project_name='exampleproject',
                                auth_url=self.TEST_URL)
-        cache = json.dumps(cl.auth_ref)
+        cache = jsonutils.dumps(cl.auth_ref)
         # Creating a HTTPClient not using session is deprecated.
         with self.deprecations.expect_deprecations_here():
-            new_client = client.Client(auth_ref=json.loads(cache))
+            new_client = client.Client(auth_ref=jsonutils.loads(cache))
         self.assertIsNotNone(new_client.auth_ref)
         with self.deprecations.expect_deprecations_here():
             self.assertTrue(new_client.auth_ref.scoped)
@@ -100,11 +101,11 @@ class KeystoneClientTest(utils.TestCase):
                                password='password',
                                project_name='exampleproject',
                                auth_url=self.TEST_URL)
-        cache = json.dumps(cl.auth_ref)
+        cache = jsonutils.dumps(cl.auth_ref)
         new_auth_url = "http://new-public:5000/v2.0"
         # Creating a HTTPClient not using session is deprecated.
         with self.deprecations.expect_deprecations_here():
-            new_client = client.Client(auth_ref=json.loads(cache),
+            new_client = client.Client(auth_ref=jsonutils.loads(cache),
                                        auth_url=new_auth_url)
         self.assertIsNotNone(new_client.auth_ref)
         with self.deprecations.expect_deprecations_here():
@@ -206,8 +207,15 @@ class KeystoneClientTest(utils.TestCase):
 
         cl = client.Client(session=sess, **opts)
 
-        for k, v in six.iteritems(opts):
+        for k, v in opts.items():
             self.assertEqual(v, getattr(cl._adapter, k))
 
         self.assertEqual('identity', cl._adapter.service_type)
         self.assertEqual((2, 0), cl._adapter.version)
+
+    def test_empty_service_catalog_param(self):
+        # Client().service_catalog should return None if the client is not
+        # authenticated
+        sess = auth_session.Session()
+        cl = client.Client(session=sess)
+        self.assertIsNone(cl.service_catalog)
